function [root, cont, xk] = regula_falsi(fname,a,b,delta)
%
% Funzione per la risoluzione dell'equazione non lineare  
%                       f(x)=0
% mediante il metodo di REGULA_FALSI
%
% INPUT: 
%    fname   nome del file (e della function!)
%            contenente la funzione non lineare 
%            a una sola variabile.
%
%      a,b   intervallo iniziale [a,b]
%            tale che f e' continua in [a,b] e f(a)f(b) < 0
%
%    delta   tolleranza (scalare non negativo).
%
% OUTPUT:
%     root   soluzione dell'equazione non lineare
%
%     cont   numero di iterazioni compiute
%     
%     xk     array contenente le approssimazioni intermedie
%

fa=feval(fname,a);
fb=feval(fname,b);
if sign(fa)==sign(fb)
    disp('intervallo iniziale che non soddisfa f(a)f(b)<0')
    return
end
if nargin==3
    delta=0.001;
end
cont=0;
fc=fa;
while (abs(a-b)>=delta) | (fc>=delta)
    c=b-fb*(b-a)/(fb-fa);
    cont=cont+1;
    xk(cont)=c;
    fc=feval(fname,c);
    if fc*fa<0
        b=c;
    else
        a=c;
    end
end
root=c;
        